      subroutine avg_pftimg (pftimg, nrot, nannuli, jcut, pixres_min,
     $     pixres_max, ann_lo, ann_hi, var, avg, sq1)

C     Computes the average and sum over squares of elements for an
C     image. Restricted to pixels within the annulus defined by (ann_lo,
C     ann_hi), with resolutions in the range (pixres_min, pixres_max),
C     and with true values of the mask var.
C
C     April 1998 Purdue University alphastation 500/400, T. Baker
C     Modified 21-Apr-1998 by T. Naker (renamed from pftcc_avg)
C     21-Jul-2006, R. Sinkovits - general cleanup and commenting

      implicit none
      
      integer*4, intent(in) :: nrot, nannuli, jcut
      integer*4, intent(in) :: ann_lo, ann_hi
      logical, intent(in)   :: var((nrot/4),nannuli)
      real*4, intent(in)    :: pftimg((nrot/4),nannuli)
      real*4, intent(in)    :: pixres_min, pixres_max

      real*4, intent(out)   :: avg, sq1

      integer*4 ir, j, jn, r
      real*4    pts, pixres, pi, twopir

      pi  = 4.0*atan2(1.0,1.0)
      avg = 0.0
      sq1 = 0.0
      pts = 0.0
      
      do ir = ann_lo,ann_hi
         r      = min(nannuli, ir+1)
         twopir = 2.0*pi*float(ir)
         do jn = jcut,((nrot/4) - 1)
            if(jn.gt.0) then    ! trap for jo
               pixres = twopir/float(jn)
            else
               pixres = 1000.0
            endif
            if(pixres.ge.pixres_max .and. pixres.le.pixres_min) then
               j = jn + 1
               if (var(j,r)) then
                  pts = pts + 1.0
                  avg = avg + pftimg(j,r)
                  sq1 = sq1 + pftimg(j,r)**2
               endif
            endif
         enddo
      enddo

      avg = avg/pts
      
      return
      end subroutine avg_pftimg
